pub enum CheckBaseError {
BaseLenTooShort(String),
DuplicateCharInBase {
base: String,
c: char,
},
}Expand description
Errors that can be returned by check_base and any function that takes a base as argument.
Variants
BaseLenTooShort(String)
Error occurring when a base length is inferior at 2.
DuplicateCharInBase
Error occurring when a character appears more than once in a base.