Enum base_converter::ConversionError
source · pub enum ConversionError {
CharNotFoundInBase {
base: String,
c: char,
},
ConversionOverflow {
base: String,
base_length: usize,
power: u32,
},
}Expand description
Errors that can be returned when converting a number between bases.
Variants
CharNotFoundInBase
Error occurring when a char in a number is not found from the base it should be in.
ConversionOverflow
Error occurring when a number encoded in a base cannot be represented in an usize.